==> apache-netbeans-java-22.9.9-sources.zip: enterprise/cloud.oracle/src/org/netbeans/modules/cloud/oracle/devops/RepositoryItem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.cloud.oracle.devops;

import java.util.List;
import org.netbeans.modules.cloud.oracle.items.OCID;
import org.netbeans.modules.cloud.oracle.items.OCIItem;

/**
 *
 * @author Jan Horvath
 */
public class RepositoryItem extends OCIItem {

    public RepositoryItem(OCID id, String compartmentId, String name) {
        super(id, compartmentId, name);
    }
    
    public static class RepositoryFolder extends OCIItem {

        private final List<RepositoryItem> repositories;

        public RepositoryFolder(OCID project, String compartmentId, String name, List<RepositoryItem> repositories) {
            super(project, compartmentId, name);
            this.repositories = repositories;
        }
    
        public List<RepositoryItem> getRepositories() {
            return repositories;
        }
    }

}

==> apache-netbeans-java-26.0.0-sources.zip: enterprise/cloud.oracle/src/org/netbeans/modules/cloud/oracle/devops/RepositoryItem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.cloud.oracle.devops;

import java.util.List;
import org.netbeans.modules.cloud.oracle.items.OCID;
import org.netbeans.modules.cloud.oracle.items.OCIItem;

/**
 *
 * @author Jan Horvath
 */
public class RepositoryItem extends OCIItem {

    public RepositoryItem(OCID id, String compartmentId, String name, String tenancyId, String regionCode) {
        super(id, compartmentId, name, tenancyId, regionCode);
    }
    
    public static class RepositoryFolder extends OCIItem {

        private final List<RepositoryItem> repositories;

        public RepositoryFolder(OCID project, String compartmentId, String name, List<RepositoryItem> repositories, String tenancyId, String regionCode) {
            super(project, compartmentId, name, tenancyId, regionCode);
            this.repositories = repositories;
        }
    
        public List<RepositoryItem> getRepositories() {
            return repositories;
        }
    }

}
